.. include:: ../../README.rst

Contents
--------

.. toctree::
   :maxdepth: 2

   contributing
   changelog


License
-------

Copyright (c) 2016 by pypt authors and contributors. See :ref:`authors`

This module is part of pytest-elasticsearch and is released under
the MIT License (MIT): http://opensource.org/licenses/MIT
